@@ -21,22 +21,6 @@ class ActivityBar:
         self.icon = icon
 
 
-class StaticWebview:
-    """
-    Content settings for a Static Webview.
-    """
-
-    def __init__(self, id: str, html: str, title: Optional[str] = None) -> None:
-        """
-        Args:
-            id: The unique id of the static webview.
-            title: The title shown to the user.
-            html: The html to rendered in the webview.
-        """
-        self.id = id
-        self.html = html
-        self.title = title
-
 
 class InputBoxOptions:
     """
@@ -186,7 +170,8 @@ class Disposable:
 
     def dispose(self):
         send_ipc("DI", [self.id])
-        time.sleep(0.1) # Makes sure it is properly disposed.
+        _ = uinput() # Awaiting confirmation
+
 
     def __enter__(self):
         pass
